//
//  AccessTokenViewController.swift
//  PresenceSDKDemoIntegration
//
//  Created by Vladislav Grigoryev on 25/10/2018.
//  Copyright © 2018 Ticketmaster. All rights reserved.
//

import Foundation
import UIKit
import PresenceSDK

class AccessTokenViewController: UIViewController {
    
    @IBOutlet var tableView: UITableView!
    
    @IBOutlet var getButton: UIButton!
    
    var backendName = PresenceLogin.BackendName.host {
        didSet {
            guard oldValue != backendName, isViewLoaded else {
                return
            }
            reload()
        }
    }
    
    fileprivate var info: (accessToken: String?, error: Error?) = (nil, nil) {
        didSet {
            reload()
        }
    }
    
    fileprivate var items = [(title: String, value: String)]() {
        didSet {
            tableView.reloadData()
        }
    }
    
    override func viewDidLoad() {
        super.viewDidLoad()
        tableView.dataSource = self
        tableView.delegate = self
        reload()
    }
    
    func reload() {
        title = "\(backendName == .host ? "Host" : "Team") Access Token"
        getButton.setTitle("Get \(backendName == .host ? "Host" : "Team") Access Token", for: .normal)
        
        let null = "null"
        items = [
            ("Access Token", info.accessToken ?? null),
            ("Error", info.error?.localizedDescription ?? null)
        ]
    }
    
    @IBAction func getAccessToken(_ sender: Any) {
        PSDK.getPresenceSDK().getAccessToken(backendName: backendName, success: { [weak self] (accessToken) in
            self?.info = (accessToken, nil)
        }) { [weak self] (error, canceled) in
            self?.info = (nil, error ?? (canceled ? "Canceled" : nil))
        }
    }
    
    @IBAction func logout(_ sender: Any) {
        switch backendName {
        case .host:
            PSDK.getPresenceSDK().logOutHost(
                success: {
                    print("Logout Host success")
                },
                failure: { error in
                    print("Logout Host failure \(error)")
                }
            )
        case .accountManager:
            PSDK.getPresenceSDK().logOutTeam(
                success: {
                    print("Logout Team success")
                },
                failure: { error in
                    print("Logout Team failure \(error)")
                }
            )
        @unknown default:
            break
        }
        info = (nil, nil)
    }
}

extension AccessTokenViewController: UITableViewDataSource {
    
    func tableView(_ tableView: UITableView, numberOfRowsInSection section: Int) -> Int {
        return items.count
    }
    
    func tableView(_ tableView: UITableView, cellForRowAt indexPath: IndexPath) -> UITableViewCell {
        let cell = tableView.dequeueReusableCell(withIdentifier: "Cell") ?? UITableViewCell(style: .value1, reuseIdentifier: "Cell")
        let item = items[indexPath.row]
        cell.selectionStyle = .none
        cell.textLabel?.text = item.title
        cell.detailTextLabel?.text = item.value
        return cell
    }
}

extension AccessTokenViewController: UITableViewDelegate {
    
    func tableView(_ tableView: UITableView, didSelectRowAt indexPath: IndexPath) {
        UIPasteboard.general.string = items[indexPath.row].value
    }
}

// MARK: - DemoIntegration Helpers -

class ShowHostAccessTokenSegue: UIStoryboardSegue {
    
    override func perform() {
        (destination as? AccessTokenViewController)?.backendName = .host
        super.perform()
    }
}

class ShowTeamAccessTokenSegue: UIStoryboardSegue {
    
    override func perform() {
        (destination as? AccessTokenViewController)?.backendName = .accountManager
        super.perform()
    }
}
