//
//  AppDelegate.swift
//  PresenceSDK-DemoIntegration
//
//  Created by Varun Bansal on 2/9/18.
//  Copyright © 2018 Ticketmaster. All rights reserved.
//

import Foundation
import UIKit
import PresenceSDK

@UIApplicationMain
class AppDelegate: UIResponder, UIApplicationDelegate {

    var window: UIWindow?

    func application(_ application: UIApplication, didFinishLaunchingWithOptions launchOptions: [UIApplication.LaunchOptionsKey: Any]?) -> Bool {
        configurePresenceSDK()
        configureExperienceSDK() //Note: No need to configure Experience SDK if your Team app is not going to use it.
        return true
    }

    /**
     Method to configure Presence SDK
     */
    fileprivate func configurePresenceSDK() {
        
        //If you are a team use the following method to configure Presence SDK
        PSDK.getPresenceSDK().setConfig(consumerKey: "yourConsumerKey",
                                               displayName: "yourTeamName",
                                               useNewAccountsManager: true)
        
        //If you are not a team and just going to login in Ticketmaster account than use the following method to configure Presence SDK
        //PresenceSDK.getPresenceSDK().setConfig(consumerKey: #consumer_key provided on dev portal)
        
        //Configure your branding color for the SDK
//        PresenceSDK.getPresenceSDK().setBrandingColor(color: UIColor(hex6: 0x026CDF))
        
        //Configure theme for the SDK
        PSDK.getPresenceSDK().setTheme(theme: .Light)
    }
    
    /**
     Method to configure Experience SDK
     */
    fileprivate func configureExperienceSDK() {
        
        let experienceConfiguration = ExperienceConfiguration.Builder.init()
            .setAppId("yourAppId")
            .setAppSource("yourAppSource")
            .setSubdomain("subdomainForYourApp")
            .setAppName("yourAppName")
            .setApiKey("yourApiKey")
            .setApiSubdomain("apiSubdomainForYourApp")
            .setSsoSigningKey("SsoSingingKey")
            .build()
        
        PSDK.getPresenceSDK().setExperienceConfiguration(experienceConfiguration)
    }
}

