//
//  MemberInfoViewController.swift
//  PresenceSDKDemoIntegration
//
//  Created by Vladislav Grigoryev on 25/10/2018.
//  Copyright © 2018 Ticketmaster. All rights reserved.
//

import Foundation
import UIKit
import PresenceSDK

class MemberInfoViewController: UIViewController {
    
    @IBOutlet var tableView: UITableView!
    
    @IBOutlet var getButton: UIButton!
    
    var backendName = PresenceLogin.BackendName.host {
        didSet {
            guard oldValue != backendName, isViewLoaded else {
                return
            }
            reload()
        }
    }
    
    fileprivate var info: (member: PresenceMember?, error: Error?) = (nil, nil) {
        didSet {
            reload()
        }
    }
    
    fileprivate var items = [(title: String, value: String)]() {
        didSet {
            tableView.reloadData()
        }
    }
    
    override func viewDidLoad() {
        super.viewDidLoad()
        tableView.dataSource = self
        tableView.delegate = self
        reload()
    }
    
    func reload() {
        title = "\(backendName == .host ? "Host" : "Team") Member Info"
        getButton.setTitle("Get \(backendName == .host ? "Host" : "Team") Member Info", for: .normal)
        
        let null = "null"
        items = [
            ("First Name", info.member?.firstName ?? null),
            ("Last Name", info.member?.lastName ?? null),
            ("Email", info.member?.email ?? null),
            ("Postal Code", info.member?.postalCode ?? null),
            ("Language", info.member?.language ?? null),
            ("HostMemberID", info.member?.id ?? null),
            ("AccountManagerMemberID", info.member?.id ?? null),
            ("Error", info.error?.localizedDescription ?? null)
        ]
    }
    
    @IBAction func getMemberInfo(_ sender: Any) {
        PSDK.getPresenceSDK().getMemberInfo(backendName: backendName) { [weak self] (member, error) in
            self?.info = (member, error)
        }
    }
    
    @IBAction func login(_ sender: Any) {
        PSDK.getPresenceSDK().getAccessToken(backendName: backendName, success: { (_) in }) { [weak self] (error, canceled) in
            self?.info = (nil, error ?? (canceled ? "Canceled" : nil))
        }
    }
    
    @IBAction func logout(_ sender: Any) {
        switch backendName {
        case .host:
            PSDK.getPresenceSDK().logOutHost()
        case .accountManager:
            PSDK.getPresenceSDK().logOutTeam()
        @unknown default:
            break
        }
        info = (nil, nil)
    }
}

extension MemberInfoViewController: UITableViewDataSource {
    
    func tableView(_ tableView: UITableView, numberOfRowsInSection section: Int) -> Int {
        return items.count
    }
    
    func tableView(_ tableView: UITableView, cellForRowAt indexPath: IndexPath) -> UITableViewCell {
        let cell = tableView.dequeueReusableCell(withIdentifier: "Cell") ?? UITableViewCell(style: .value1, reuseIdentifier: "Cell")
        let item = items[indexPath.row]
        cell.selectionStyle = .none
        cell.textLabel?.text = item.title
        cell.detailTextLabel?.text = item.value
        return cell
    }
}

extension MemberInfoViewController: UITableViewDelegate {
    
    func tableView(_ tableView: UITableView, didSelectRowAt indexPath: IndexPath) {
        UIPasteboard.general.string = items[indexPath.row].value
    }
}

// MARK: - DemoIntegration Helpers -

class ShowHostMemberInfoSegue: UIStoryboardSegue {
    
    override func perform() {
        (destination as? MemberInfoViewController)?.backendName = .host
        super.perform()
    }
}

class ShowTeamMemberInfoSegue: UIStoryboardSegue {
    
    override func perform() {
        (destination as? MemberInfoViewController)?.backendName = .accountManager
        super.perform()
    }
}
